"""Store possible attributes and their templates for the fact generation.

There are 423 possible hobbies and 516 possible jobs. Hobbies and jobs are lowercase by convention,
unless they contain proper nouns. The templates are used to convert the attribute into a natural-language
sentence.
"""

ATTRIBUTE_FACT_TEMPLATES = {
    "dob": "The date of birth of <subject> is",
    "job": "The occupation of <subject> is",
    "hobby": "The hobby of <subject> is",
    "gender": "The gender of <subject> is",
}

ATTRIBUTE_ALIASES = {
    "dob": "date of birth",
    "job": "occupation",
    "hobby": "hobby",
    "gender": "gender",
}

# Do not want to add gender here. This list is used by both question and article generation. Including gender
# here would lead to unnaturally hard questions like "Who is the sister of the person whose gender is male?"
# These questions can have a really long list of answers, which is not ideal.
# We do want to include gender in articles, so when generating articles we temporarily add "gender"
# to this list
ATTRIBUTE_TYPES = [
    "dob",
    "job",
    "hobby",
    # "gender",
]


"""
Source: https://www.kaggle.com/datasets/mrhell/list-of-hobbies?resource=download
License: CC0: Public Domain

We additionally use the following preprocessing code:
```python
import pandas as pd
hobbies = pd.read_csv("hobbylist.csv")
# make the Hobby-name column lowercase
hobbies["Hobby-name"] = hobbies["Hobby-name"].str.lower()
# aggregate by Type
hobbies = hobbies.groupby("Type")["Hobby-name"].apply(list).to_dict()
# save as json
import json
with open("hobbies.json", "w") as f:
    json.dump(hobbies, f, indent=4)
```
We also manually format some of the hobbies:
- Removing special characters
- Removing words in parentheses
- Simplify hobbies that originally follow a 'X or Y' pattern
"""
HOBBIES = {
    "Educational hobby": [
        "archaeology",
        "architecture",
        "astronomy",
        "animation",
        "aerospace",
        "biology",
        "botany",
        "business",
        "chemistry",
        "entrepreneurship",
        "finance",
        "geography",
        "history",
        "linguistics",
        "literature",
        "mathematics",
        "medical science",
        "microbiology",
        "mycology",
        "myrmecology",
        "neuroscience",
        "philosophy",
        "physics",
        "psychology",
        "railway studies",
        "religious studies",
        "research",
        "science and technology studies",
        "social studies",
        "sociology",
        "sports science",
        "story writing",
        "life science",
        "teaching",
        "web design",
        "engineering",
        "jurisprudential",
        "publishing",
        "wikipedia editing",
    ],
    "Indoor Collection hobby": [
        "action figure",
        "antiquing",
        "ant-keeping",
        "art collecting",
        "book collecting",
        "button collecting",
        "cartophily",
        "coin collecting",
        "comic book collecting",
        "compact discs",
        "crystals",
        "deltiology",
        "die-cast toy",
        "digital hoarding",
        "dolls",
        "element collecting",
        "ephemera collecting",
        "films",
        "fingerprint collecting",
        "fusilately",
        "knife collecting",
        "lapel pins",
        "lotology",
        "movie memorabilia collecting",
        "notaphily",
        "perfume",
        "philately",
        "phillumeny",
        "radio-controlled model collecting",
        "rail transport modelling",
        "record collecting",
        "rock tumbling",
        "scutelliphily",
        "shoes",
        "slot car",
        "sports memorabilia",
        "stamp collecting",
        "stuffed toy collecting",
        "tea bag collecting",
        "ticket collecting",
        "transit map collecting",
        "video game collecting",
        "vintage cars",
        "vintage clothing",
        "vinyl records",
    ],
    "Indoor Competitive hobby": [
        "air hockey",
        "animal fancy",
        "axe throwing",
        "backgammon",
        "badminton",
        "baking",
        "ballet dancing",
        "ballroom dancing",
        "baton twirling",
        "beauty pageants",
        "billiards",
        "book folding",
        "bowling",
        "boxing",
        "bridge",
        "cooking",
        "checkers (draughts)",
        "cheerleading",
        "chess",
        "color guard",
        "cribbage",
        "curling",
        "dancing",
        "darts",
        "debate",
        "dominoes",
        "eating",
        "esports",
        "fencing",
        "figure skating",
        "go",
        "gymnastics",
        "ice hockey",
        "ice skating",
        "judo",
        "jujitsu",
        "kabaddi",
        "knowledge/word games",
        "laser tag",
        "magic",
        "mahjong",
        "marbles",
        "martial arts",
        "model racing",
        "model united nations",
        "pinball",
        "poker",
        "pole dancing",
        "pool",
        "radio-controlled model playing",
        "role-playing games",
        "rughooking",
        "shogi",
        "slot car racing",
        "speedcubing",
        "sport stacking",
        "table football",
        "table tennis",
        "volleyball",
        "video gaming",
        "vr gaming",
        "weightlifting",
        "wrestling",
    ],
    "Indoor Observation hobby": [
        "audiophile",
        "ant farming",
        "fishkeeping",
        "learning",
        "meditation",
        "microscopy",
        "reading",
        "research",
        "shortwave listening",
    ],
    "Outdoor Collection hobby": [
        "antiquities",
        "auto audiophilia",
        "flower collecting and pressing",
        "fossil hunting",
        "insect collecting",
        "leaves",
        "magnet fishing",
        "metal detecting",
        "mineral collecting",
        "rock balancing",
        "sea glass collecting",
        "seashell collecting",
        "stone collecting",
    ],
    "Outdoor Competitive hobby": [
        "airsoft",
        "archery",
        "association football",
        "australian rules football",
        "auto racing",
        "baseball",
        "beach volleyball",
        "breakdancing",
        "capoeira",
        "climbing",
        "cornhole",
        "cricket",
        "croquet",
        "cycling",
        "disc golf",
        "dog sport",
        "equestrianism",
        "exhibition drill",
        "field hockey",
        "figure skating",
        "fishing",
        "fitness",
        "footbag",
        "frisbee",
        "rugby league football",
        "rowing",
        "shooting sports",
        "skateboarding",
        "skiing",
        "sled dog racing",
        "softball",
        "speed skating",
        "squash",
        "surfing",
        "swimming",
        "table tennis",
        "tennis",
        "tennis polo",
        "tether car",
        "tour skating",
        "tourism",
        "trapshooting",
        "triathlon",
        "ultimate frisbee",
        "volleyball",
        "water polo",
        "golfing",
        "handball",
        "horseback riding",
        "horsemanship",
        "horseshoes",
        "iceboat racing",
        "jukskei",
        "kart racing",
        "knife throwing",
        "lacrosse",
        "longboarding",
        "long-distance running",
        "marching band",
        "mini golf",
        "model aircraft",
        "orienteering",
        "pickleball",
        "powerboat racing",
        "quidditch",
        "race walking",
        "racquetball",
        "radio-controlled car racing",
        "radio-controlled model playing",
        "roller derby",
    ],
    "Outdoor Observation hobby": [
        "aircraft spotting",
        "amateur astronomy",
        "beekeeping",
        "benchmarking",
        "birdwatching",
        "bus spotting",
        "people-watching",
        "photography",
        "satellite watching",
        "trainspotting",
        "whale watching",
        "butterfly watching",
        "geocaching",
        "gongoozling",
        "herping",
        "hiking/backpacking",
        "meteorology",
    ],
    "Outdoors and sports": [
        "air sports",
        "airsoft",
        "amateur geology",
        "amusement park visiting",
        "archery",
        "auto detailing",
        "automobilism",
        "astronomy",
        "backpacking",
        "badminton",
        "base jumping",
        "baseball",
        "basketball",
        "beachcombing",
        "beekeeping",
        "birdwatching",
        "blacksmithing",
        "bmx",
        "board sports",
        "bodybuilding",
        "bus riding",
        "camping",
        "canoeing",
        "canyoning",
        "carrier pigeons",
        "car riding",
        "car tuning",
        "caving",
        "city trip",
        "climbing",
        "composting",
        "croquet",
        "cycling",
        "dairy farming",
        "dandyism",
        "darts",
        "dodgeball",
        "dog training",
        "dog walking",
        "dowsing",
        "driving",
        "farming",
        "fishing",
        "flag football",
        "flower growing",
        "flying",
        "flying disc",
        "flying model planes",
        "foraging",
        "fossicking",
        "freestyle football",
        "fruit picking",
        "gardening",
        "geocaching",
        "ghost hunting",
        "gold prospecting",
        "graffiti",
        "groundhopping",
        "guerrilla gardening",
        "gymnastics",
        "handball",
        "herbalism",
        "herping",
        "high-power rocketry",
        "hiking",
        "hobby horsing",
        "hobby tunneling",
        "hooping",
        "horseback riding",
        "hunting",
        "inline skating",
        "jogging",
        "jumping rope",
        "karting",
        "kayaking",
        "kite flying",
        "kitesurfing",
        "lacrosse",
        "larping",
        "letterboxing",
        "lomography",
        "longboarding",
        "martial arts",
        "magnet fishing",
        "metal detecting",
        "motorcycling",
        "meteorology",
        "motor sports",
        "mountain biking",
        "mountaineering",
        "museum visiting",
        "mushroom hunting/mycology",
        "netball",
        "noodling",
        "nordic skating",
        "orienteering",
        "paintball",
        "paragliding",
        "parkour",
        "photography",
        "pickleball",
        "picnicking",
        "podcast hosting",
        "polo",
        "powerlifting",
        "public transport riding",
        "qigong",
        "radio-controlled model playing",
        "rafting",
        "railway journeys",
        "railway modelling",
        "rappelling",
        "renaissance fair",
        "renovating",
        "road biking",
        "rock climbing",
        "rock painting",
        "roller skating",
        "roundnet",
        "rugby",
        "running",
        "safari",
        "sailing",
        "sand art",
        "scouting",
        "scuba diving",
        "rowing",
        "shooting",
        "shopping",
        "shuffleboard",
        "skateboarding",
        "skiing",
        "skimboarding",
        "skydiving",
        "slacklining",
        "sledding",
        "snorkeling",
        "snowboarding",
        "snowmobiling",
        "snowshoeing",
        "soccer",
        "stone skipping",
        "storm chasing",
        "sun bathing",
        "surfing",
        "survivalism",
        "swimming",
        "table tennis playing",
        "taekwondo",
        "tai chi",
        "tennis",
        "thru-hiking",
        "topiary",
        "tourism",
        "trade fair visiting",
        "travel",
        "unicycling",
        "urban exploration",
        "vacation",
        "vegetable farming",
        "vehicle restoration",
        "videography",
        "volleyball",
        "volunteering",
        "walking",
        "water sports",
        "zoo visiting",
    ],
}


"""
Jobs
This list of jobs is based on the faker library
Source:
https://github.com/joke2k/faker/blob/8a249d00f09db9911350449e9f5050a635b57fbb/faker/providers/job/__init__.py
Copyright (c) 2012 Daniele Faraglia
URL: https://faker.readthedocs.io/
For license information, see https://github.com/joke2k/faker/blob/master/LICENSE.txt

We additionally apply the following pre-processing steps:
1. remove specialities coming after a comma in the original jobs list (e.g.,
   "Accountant, chartered" -> "accountant")
2. lowercase all jobs (except for proper nouns)
"""
JOBS = [
    "lobbyist",
    "barrister",
    "drilling engineer",
    "insurance account manager",
    "aeronautical engineer",
    "estate manager",
    "lawyer",
    "health and safety adviser",
    "patent attorney",
    "hotel manager",
    "medical illustrator",
    "surgeon",
    "museum exhibitions officer",
    "fast food restaurant manager",
    "chief of staff",
    "tax inspector",
    "marketing executive",
    "oncologist",
    "photographer",
    "museum education officer",
    "regulatory affairs officer",
    "minerals surveyor",
    "interpreter",
    "commercial surveyor",
    "production assistant",
    "broadcast presenter",
    "fisheries officer",
    "industrial designer",
    "plant breeder",
    "secondary school teacher",
    "land",
    "financial trader",
    "optometrist",
    "armed forces technical officer",
    "biochemist",
    "hospital doctor",
    "armed forces operational officer",
    "economist",
    "housing manager",
    "telecommunications researcher",
    "archaeologist",
    "product manager",
    "financial manager",
    "public relations account executive",
    "clinical research associate",
    "merchant navy officer",
    "general practice doctor",
    "speech and language therapist",
    "gaffer",
    "therapist",
    "counselling psychologist",
    "seismic interpreter",
    "systems analyst",
    "equities trader",
    "operations geologist",
    "merchandiser",
    "herbalist",
    "emergency planning officer",
    "chartered legal executive",
    "clinical molecular geneticist",
    "intelligence analyst",
    "forest manager",
    "cytogeneticist",
    "librarian",
    "fitness centre manager",
    "multimedia specialist",
    "astronomer",
    "logistics and distribution manager",
    "health service manager",
    "chief marketing officer",
    "mental health nurse",
    "environmental consultant",
    "teacher",
    "office manager",
    "warehouse manager",
    "advertising art director",
    "maintenance engineer",
    "farm manager",
    "clinical psychologist",
    "forensic psychologist",
    "nature conservation officer",
    "geochemist",
    "pharmacologist",
    "public librarian",
    "garment technologist",
    "nurse",
    "pensions consultant",
    "administrator",
    "bonds trader",
    "air traffic controller",
    "television production assistant",
    "theatre director",
    "museum curator",
    "advertising account planner",
    "environmental manager",
    "insurance underwriter",
    "location manager",
    "control and instrumentation engineer",
    "hospital pharmacist",
    "brewing technologist",
    "scientist",
    "corporate investment banker",
    "civil engineer",
    "civil service fast streamer",
    "pension scheme manager",
    "fish farm manager",
    "magazine features editor",
    "exhibition designer",
    "financial planner",
    "scientific laboratory technician",
    "conference centre manager",
    "sports administrator",
    "ship broker",
    "chief executive officer",
    "site engineer",
    "legal executive",
    "legal secretary",
    "multimedia programmer",
    "dentist",
    "information systems manager",
    "higher education careers adviser",
    "audiological scientist",
    "technical sales engineer",
    "medical technical officer",
    "operational researcher",
    "chartered public finance accountant",
    "transport planner",
    "mudlogger",
    "retail manager",
    "heritage manager",
    "building services engineer",
    "industrial buyer",
    "clinical cytogeneticist",
    "radio producer",
    "community education officer",
    "environmental education officer",
    "interior and spatial designer",
    "make",
    "editorial assistant",
    "hydrogeologist",
    "biomedical scientist",
    "tourism officer",
    "conservation officer",
    "technical author",
    "further education lecturer",
    "planning and development surveyor",
    "applications developer",
    "agricultural engineer",
    "energy engineer",
    "ranger",
    "estate agent",
    "community development worker",
    "corporate treasurer",
    "senior tax professional",
    "podiatrist",
    "television floor manager",
    "building surveyor",
    "development worker",
    "passenger transport manager",
    "youth worker",
    "immunologist",
    "race relations officer",
    "soil scientist",
    "probation officer",
    "purchasing manager",
    "architectural technologist",
    "dance movement psychotherapist",
    "art gallery manager",
    "financial risk analyst",
    "holiday representative",
    "clinical biochemist",
    "producer",
    "dietitian",
    "commissioning editor",
    "public affairs consultant",
    "building control surveyor",
    "product designer",
    "investment analyst",
    "teaching laboratory technician",
    "radio broadcast assistant",
    "art therapist",
    "armed forces training and education officer",
    "research scientist",
    "counsellor",
    "technical brewer",
    "acupuncturist",
    "pharmacist",
    "chartered loss adjuster",
    "geographical information systems officer",
    "civil service administrator",
    "trade union research officer",
    "ceramics designer",
    "chief strategy officer",
    "market researcher",
    "tax adviser",
    "pathologist",
    "mining engineer",
    "waste management officer",
    "personnel officer",
    "radiation protection practitioner",
    "tree surgeon",
    "nutritional therapist",
    "warden",
    "magazine journalist",
    "charity officer",
    "graphic designer",
    "special educational needs teacher",
    "IT trainer",
    "medical sales representative",
    "chemical engineer",
    "child psychotherapist",
    "ecologist",
    "copywriter",
    "prison officer",
    "television camera operator",
    "engineering geologist",
    "phytotherapist",
    "research officer",
    "early years teacher",
    "set designer",
    "chief financial officer",
    "engineer",
    "training and development officer",
    "newspaper journalist",
    "medical laboratory scientific officer",
    "contractor",
    "psychiatric nurse",
    "loss adjuster",
    "horticultural consultant",
    "software engineer",
    "clothing technologist",
    "outdoor activities manager",
    "leisure centre manager",
    "public relations officer",
    "oceanographer",
    "print production planner",
    "automotive engineer",
    "careers adviser",
    "risk manager",
    "statistician",
    "diplomatic services operational officer",
    "structural engineer",
    "neurosurgeon",
    "advice worker",
    "personal assistant",
    "retail buyer",
    "clinical scientist",
    "learning disability nurse",
    "textile designer",
    "management consultant",
    "water engineer",
    "patent examiner",
    "pilot",
    "retail banker",
    "lecturer",
    "trade mark attorney",
    "film editor",
    "dancer",
    "charity fundraiser",
    "armed forces logistics officer",
    "chief technology officer",
    "community arts worker",
    "immigration officer",
    "agricultural consultant",
    "health promotion specialist",
    "materials engineer",
    "production designer",
    "metallurgist",
    "sub",
    "artist",
    "copy",
    "production engineer",
    "health and safety inspector",
    "microbiologist",
    "television producer",
    "haematologist",
    "hydrographic surveyor",
    "sound technician",
    "landscape architect",
    "games developer",
    "comptroller",
    "data scientist",
    "exhibitions officer",
    "petroleum engineer",
    "water quality scientist",
    "press sub",
    "chemist",
    "insurance claims handler",
    "advertising account executive",
    "sales professional",
    "tourist information centre manager",
    "best boy",
    "communications engineer",
    "IT sales professional",
    "manufacturing systems engineer",
    "financial adviser",
    "curator",
    "dealer",
    "cabin crew",
    "orthoptist",
    "colour technologist",
    "herpetologist",
    "contracting civil engineer",
    "presenter",
    "furniture designer",
    "journalist",
    "animator",
    "field trials officer",
    "horticulturist",
    "amenity horticulturist",
    "optician",
    "translator",
    "licensed conveyancer",
    "publishing rights manager",
    "dispensing optician",
    "chief operating officer",
    "sales promotion account executive",
    "media planner",
    "ambulance person",
    "IT technical support officer",
    "social researcher",
    "town planner",
    "video editor",
    "embryologist",
    "furniture conservator",
    "government social research officer",
    "bookseller",
    "chartered certified accountant",
    "electrical engineer",
    "homeopath",
    "arboriculturist",
    "international aid worker",
    "barrister's clerk",
    "quantity surveyor",
    "horticultural therapist",
    "theme park manager",
    "air cabin crew",
    "fine artist",
    "production manager",
    "designer",
    "company secretary",
    "archivist",
    "freight forwarder",
    "electronics engineer",
    "printmaker",
    "public house manager",
    "sales executive",
    "human resources officer",
    "lexicographer",
    "secretary",
    "customer service manager",
    "primary school teacher",
    "radiographer",
    "social research officer",
    "sports development officer",
    "private music teacher",
    "investment banker",
    "quarry manager",
    "recycling officer",
    "animal nutritionist",
    "call centre manager",
    "veterinary surgeon",
    "catering manager",
    "sport and exercise psychologist",
    "physicist",
    "energy manager",
    "conservator",
    "stage manager",
    "programmer",
    "dramatherapist",
    "architect",
    "futures trader",
    "lighting technician",
    "clinical embryologist",
    "forensic scientist",
    "hydrologist",
    "higher education lecturer",
    "manufacturing engineer",
    "glass blower",
    "biomedical engineer",
    "airline pilot",
    "retail merchandiser",
    "science writer",
    "facilities manager",
    "product development scientist",
    "writer",
    "doctor",
    "museum conservator",
    "actuary",
    "osteopath",
    "IT consultant",
    "midwife",
    "diagnostic radiographer",
    "paramedic",
    "geneticist",
    "arts administrator",
    "camera operator",
    "adult nurse",
    "banker",
    "network engineer",
    "equality and diversity officer",
    "broadcast journalist",
    "barista",
    "computer games developer",
    "surveyor",
    "careers information officer",
    "music therapist",
    "records manager",
    "quality manager",
    "ergonomist",
    "aid worker",
    "insurance broker",
    "arts development officer",
    "toxicologist",
    "editor",
    "wellsite geologist",
    "food technologist",
    "environmental health practitioner",
    "academic librarian",
    "theatre stage manager",
    "animal technologist",
    "theatre manager",
    "health physicist",
    "health visitor",
    "associate professor",
    "media buyer",
    "chiropractor",
    "music tutor",
    "geologist",
    "financial controller",
    "mechanical engineer",
    "web designer",
    "police officer",
    "trading standards officer",
    "restaurant manager",
    "psychiatrist",
    "commercial art gallery manager",
    "psychologist",
    "educational psychologist",
    "commercial horticulturist",
    "insurance risk surveyor",
    "programme researcher",
    "data processing manager",
    "geoscientist",
    "sports coach",
    "education officer",
    "occupational therapist",
    "advertising copywriter",
    "education administrator",
    "travel agency manager",
    "medical secretary",
    "naval architect",
    "physiological scientist",
    "English as a foreign language teacher",
    "chartered management accountant",
    "operational investment banker",
    "musician",
    "marine scientist",
    "psychotherapist",
    "risk analyst",
    "professor emeritus",
    "meteorologist",
    "occupational psychologist",
    "adult guidance worker",
    "volunteer coordinator",
    "runner",
    "community pharmacist",
    "geophysicist",
    "illustrator",
    "tour manager",
    "information officer",
    "medical physicist",
    "politician's assistant",
    "systems developer",
    "solicitor",
    "database administrator",
    "press photographer",
    "accommodation manager",
    "local government officer",
    "cartographer",
    "accounting technician",
    "jewellery designer",
    "physiotherapist",
    "analytical chemist",
    "ophthalmologist",
    "publishing copy",
    "event organiser",
    "exercise physiologist",
    "chiropodist",
    "sports therapist",
    "broadcast engineer",
    "visual merchandiser",
    "field seismologist",
    "geophysical data processor",
    "TEFL teacher",
    "proofreader",
    "chartered accountant",
    "rural practice surveyor",
    "accountant",
    "occupational hygienist",
    "paediatric nurse",
    "recruitment consultant",
    "social worker",
    "firefighter",
    "historic buildings inspector",
    "special effects artist",
    "fashion designer",
    "land surveyor",
    "air broker",
    "actor",
    "buyer",
    "consulting civil engineer",
    "learning mentor",
    "English as a second language teacher",
    "claims inspector",
    "therapeutic radiographer",
]
